#
# spec file for package python-pudb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upstream_name pudb
%define module_name pudb
%define py_maj_ver %(c=%{python})
%{?sle15_python_module_pythons}
Name:           python-pudb
Version:        2024.1.3
Release:        1.2
Summary:        A full-screen, console-based Python debugger
License:        MIT
Group:          Development/Tools/Debuggers
URL:            https://github.com/inducer/pudb
Source0:        https://files.pythonhosted.org/packages/source/p/%{upstream_name}/%{upstream_name}-%{version}.tar.gz
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module urwid >= 2.4}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments >= 2.7.4
Requires:       python-jedi >= 0.18
Requires:       python-packaging >= 20.0
Requires:       python-urwid >= 2.4
Requires:       python-urwid-readline
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
PuDB is a full-screen, console-based visual debugger for Python.
Control is by keyboard. The UI is reminiscient of the DOS versions
of Turbo Pascal.

%prep
%autosetup -p1 -n %{upstream_name}-%{version}
sed -i '1{\@^#! %{_bindir}/env python@d}' pudb/debugger.py
rm -v LICENSE~

%build
%pyproject_wheel

%install
%pyproject_install
mv -v %{buildroot}%{_bindir}/pudb{*,} || /bin/true
%python_clone -a %{buildroot}%{_bindir}/pudb
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%pre
# Since /usr/bin/pudb became ghosted to be used with
# update-alternatives, we have to get rid of the old binary resulting
# from the non-update-alternatives-ified package:
[ -h %{_bindir}/pudb ] || rm -vf %{_bindir}/pudb

%post
%python_install_alternative pudb

%postun
%python_uninstall_alternative pudb

%check
export LC_ALL=en_US.utf8
# https://github.com/inducer/pudb/issues/304
%pytest -k 'not test_get_lines'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/%{module_name}
%{python_sitelib}/%{module_name}*-info
%python_alternative %{_bindir}/pudb

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.3:
  * Fix startup when no write permissions
  * Fix compatibility with Python 3.13
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.2:
  * Switch to ruff, fix issues
  * Break out of search loop after deleting watch
  * Fix separate-terminal debugging
  * Fix typos, add typos CI
- update to 2024.1.1:
  * Track some `urwid.util` deprecations
  * ci: add dependabot updates for github actions
  * Bump actions/checkout from 3 to 4
  * Redirect pudb warnings to built-in console
  * Catch IndexError on empty Variables state
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1:
  * Show shell error messages in fallback shell
  * Improve zsh completion
  * Fix intersphinx mapping format
  * Use deque with maxsize for command line history
  * Restore cmdline text input when browsing history
  * Give each theme its own file
  * Revise UI elements for legibility
  * Remove dependence on telnetlib which was removed in python 3.13
* Wed Aug 30 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.1.3
  * Improve sidebar help
  * Bump version to 2022.1.3
  * Remove reference to py.test in favor of pytest
  * Bump versions of various github actions components
  * Fix the midnight theme (#508)
  * Remove old reference to master
  * Implement "--continue" CLI arg (alias "-c") (#559)
  * Save cwd and use for restart
  * Fix setting of sys.path from name of script (closes gh-557)
  * Fix zsh completion of `--pre-run` (#554)
  * Support more shells by shtab
  * Ignore B024 for abstract base classes with in var_view
  * Add zsh completion support for `--pre-run`
  * Generate zsh completion script automatically
  * Fix test_executable_lines for Python 3.11
  * Fix critical bug when re-entering IPython 8.0.0 (and later) external shell (#533)
  * Get terminal size using os.get_terminal_size() (#536)
  * Close tty file when dne querying terminal info
  * Close history file after reading
  * makedirs(exist_ok=True) during config path finding
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.1.2
  * Syntax-highlighted source, the stack, breakpoints and variables are all visible at once and continuously updated.
    This helps you be more aware of what’s going on in your program. Variable displays can be expanded, collapsed and have various customization options.
  * Pre-bundled themes, including dark themes via “Ctrl-P”. Could set a custom theme also.
  * Simple, keyboard-based navigation using single keystrokes makes debugging quick and easy.
    PuDB understands cursor-keys and Vi shortcuts for navigation. Other keys are inspired by the corresponding pdb commands.
  * Use search to find relevant source code, or use “m” to invoke the module browser that shows loaded modules, lets you load new ones and reload existing ones.
  * Breakpoints can be set just by pointing at a source line and hitting “b” and then edited visually in the breakpoints window.
    Or hit “t” to run to the line under the cursor.
  * Drop to a Python shell in the current environment by pressing “!”. Or open a command prompt alongside the source-code via “Ctrl-X”.
  * PuDB places special emphasis on exception handling. A post-mortem mode makes it easy to retrace a crashing program’s last steps.
  * Ability to control the debugger from a separate terminal.
  * IPython integration (see wiki)
  * Should work with Python 3.6 and newer. (Versions 2019.2 and older continue to support Python 2.7.)
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 2021.2.2
  * no upstream changelog found
* Tue Jan 19 2021 Matej Cepl <mcepl@suse.com>
  * Update to 2020.1:
  - Use Jedi for completion in the built-in shell
  - Add vi keys for sidebar
  - Clean up vi key handling, remove duplication
  - add -m switch to run as module
  - Require Py3.6
  - Use h/l to collapse/open containers in var view
  - feat: add reverse remote pudb
  * Fix dealing with alternatives.
* Tue Apr 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Mar 19 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2019.2
  * Show the value of numpy scalars when using the safe stringifier
  * Support Py3.8
  * Bug fixes
* Wed Aug 14 2019 <eyecreate@gmail.com>
- Added package runtime requirements.
* Thu May 16 2019 ranand@suse.com
- Update to 2019.1:
  * Allow 'space' as a key to expand variables
  * Have a persistent setting on variable visibility
  * Enable/partially automate opening the debugger in another
    terminal
  * Make sidebar scrollable with j/k
  * Bug fixes
* Fri Jul 27 2018 jengelh@inai.de
- Trim filler wording and replace by concrete statements.
* Mon Jul  2 2018 mcepl@suse.com
- Update to 2018.1:
  * Show variables that start with an underscore in the var view
  * Show length of array types in var view
  * Don't crash on var state changes if no variable shown
  * set socket REUSEADDR opt for the remote debugger
  * set default value of 'Go to Line' to None instead of empty string
  * update Go-to-Line UI with File/Current Line/Go to Line
  * Placate new Flake8; add some license headers
  * check 'safely_stringify_for_pudb' on the type #276
  * Use urwid.util.calc_text_pos() in make_canvas()
  * Use text_width() in var_view
  * Create text_width() help function for getting the (terminal) width of…
  * Don't return early when "returning" from a module
* Mon Jul  2 2018 mcepl@suse.com
- Setup alterantives
* Mon Jul  2 2018 mcepl@suse.com
- Initial packaging effort
- Packaged 2017.1.4
- Enabled tests, with TestFileSourceCodeProvider.test_get_lines
  excluded (https://github.com/inducer/pudb/issues/304)
